|Build Status|

AWS boto3 helper libs
=====================

Features
--------

-  Common use cases covered under single methods
-  Keeps build files clean and powerfull

Installation
------------

You can install exr-builder from the Python Package Index (PyPI) or from
source.

Using pip

.. code:: bash

   $ pip install exr-aws

Using easy_install

.. code:: bash

   $ easy_install exr-aws

Example
-------

TODO

Contributors/Contributing
-------------------------

If you want to make changes the repo is at
https://github.com/exrny/exr-aws. You will need
`pytest <http://www.pytest.org>`__ to run the tests and
`exr-builder <https://github.com/exrny/exr-aws>`__ tool to build modules

.. code:: bash

   $ nb test

It will be great if you can raise a `pull
request <https://help.github.com/articles/using-pull-requests>`__ once
you are done.

If you find any bugs or need new features please raise a ticket in the
`issues section <https://github.com/exrny/exr-aws/issues>`__ of the
github repo.

License
-------

exr-builder is licensed under a `MIT
license <http://opensource.org/licenses/MIT>`__

.. |Build Status| image:: https://travis-ci.org/exrny/exr-aws.png?branch=master
   :target: https://travis-ci.org/exrny/exr-aws
